@@ -195,7 +195,7 @@ class LatchPersistence(DataPersistence):
                 _os.makedirs(dir, exist_ok=True)
                 task_tuples.append((url, local_file_path))
 
-            pool = ThreadPool(100)
+            pool = ThreadPool(-1)
             pool.map(get, task_tuples)
             pool.start()
             pool.wait_completion()
